@@ -174,12 +174,12 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import cdk8s
-import constructs
+import cdk8s as _cdk8s_d3d9af27
+import constructs as _constructs_77d1e7e8
 
 
 class Jenkins(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk8s-jenkins.Jenkins",
 ):
@@ -187,14 +187,14 @@ class Jenkins(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        base_plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
+        base_plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[builtins.str, typing.Any]]]] = None,
         disable_csrf_protection: typing.Optional[builtins.bool] = None,
-        metadata: typing.Optional[typing.Union[cdk8s.ApiObjectMetadata, typing.Dict[str, typing.Any]]] = None,
-        plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
-        seed_jobs: typing.Optional[typing.Sequence[typing.Union["SeedJob", typing.Dict[str, typing.Any]]]] = None,
+        metadata: typing.Optional[typing.Union[_cdk8s_d3d9af27.ApiObjectMetadata, typing.Dict[builtins.str, typing.Any]]] = None,
+        plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[builtins.str, typing.Any]]]] = None,
+        seed_jobs: typing.Optional[typing.Sequence[typing.Union["SeedJob", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -206,18 +206,7 @@ class Jenkins(
         :param seed_jobs: List of seed job configuration for Jenkins resource. For more information about seed jobs, please take a look at { @link https://github.com/jenkinsci/job-dsl-plugin/wiki/Tutorial---Using-the-Jenkins-Job-DSL Jenkins Seed Jobs Documentation }. Default: - No seed jobs
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                base_plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[str, typing.Any]]]] = None,
-                disable_csrf_protection: typing.Optional[builtins.bool] = None,
-                metadata: typing.Optional[typing.Union[cdk8s.ApiObjectMetadata, typing.Dict[str, typing.Any]]] = None,
-                plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[str, typing.Any]]]] = None,
-                seed_jobs: typing.Optional[typing.Sequence[typing.Union[SeedJob, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__72446e34172d3900118a01d2f5e7fe405c06fd092747e126f4819104c9f6d7d3)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = JenkinsProps(
@@ -237,9 +226,7 @@ class Jenkins(
         :param base_plugins: List of base plugins.
         '''
         if __debug__:
-            def stub(*base_plugins: Plugin) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__edc4fd6cb9750a65e94c6c1c74a03d3e5465f85379bd8321d629a5047bead71d)
             check_type(argname="argument base_plugins", value=base_plugins, expected_type=typing.Tuple[type_hints["base_plugins"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addBasePlugins", [*base_plugins]))
 
@@ -250,9 +237,7 @@ class Jenkins(
         :param plugins: List of custom plugins.
         '''
         if __debug__:
-            def stub(*plugins: Plugin) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2a208fc11ec0b64c7c29ad72d3b747209215402bf303d0e87f9a1c27deabd6dd)
             check_type(argname="argument plugins", value=plugins, expected_type=typing.Tuple[type_hints["plugins"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addPlugins", [*plugins]))
 
@@ -263,9 +248,7 @@ class Jenkins(
         :param seed_jobs: List of seed jobs.
         '''
         if __debug__:
-            def stub(*seed_jobs: SeedJob) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__37b0c91af96e55de36855241220aef3530626841a1131387d44e140e073c145d)
             check_type(argname="argument seed_jobs", value=seed_jobs, expected_type=typing.Tuple[type_hints["seed_jobs"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addSeedJobs", [*seed_jobs]))
 
@@ -285,11 +268,11 @@ class JenkinsProps:
     def __init__(
         self,
         *,
-        base_plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
+        base_plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[builtins.str, typing.Any]]]] = None,
         disable_csrf_protection: typing.Optional[builtins.bool] = None,
-        metadata: typing.Optional[typing.Union[cdk8s.ApiObjectMetadata, typing.Dict[str, typing.Any]]] = None,
-        plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
-        seed_jobs: typing.Optional[typing.Sequence[typing.Union["SeedJob", typing.Dict[str, typing.Any]]]] = None,
+        metadata: typing.Optional[typing.Union[_cdk8s_d3d9af27.ApiObjectMetadata, typing.Dict[builtins.str, typing.Any]]] = None,
+        plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[builtins.str, typing.Any]]]] = None,
+        seed_jobs: typing.Optional[typing.Sequence[typing.Union["SeedJob", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Props for ``Jenkins``.
 
@@ -300,24 +283,15 @@ class JenkinsProps:
         :param seed_jobs: List of seed job configuration for Jenkins resource. For more information about seed jobs, please take a look at { @link https://github.com/jenkinsci/job-dsl-plugin/wiki/Tutorial---Using-the-Jenkins-Job-DSL Jenkins Seed Jobs Documentation }. Default: - No seed jobs
         '''
         if isinstance(metadata, dict):
-            metadata = cdk8s.ApiObjectMetadata(**metadata)
+            metadata = _cdk8s_d3d9af27.ApiObjectMetadata(**metadata)
         if __debug__:
-            def stub(
-                *,
-                base_plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[str, typing.Any]]]] = None,
-                disable_csrf_protection: typing.Optional[builtins.bool] = None,
-                metadata: typing.Optional[typing.Union[cdk8s.ApiObjectMetadata, typing.Dict[str, typing.Any]]] = None,
-                plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[str, typing.Any]]]] = None,
-                seed_jobs: typing.Optional[typing.Sequence[typing.Union[SeedJob, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1a459058700d681813edb30fad5bba411efe07ec08e129aedf47aceff4bc7536)
             check_type(argname="argument base_plugins", value=base_plugins, expected_type=type_hints["base_plugins"])
             check_type(argname="argument disable_csrf_protection", value=disable_csrf_protection, expected_type=type_hints["disable_csrf_protection"])
             check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
             check_type(argname="argument plugins", value=plugins, expected_type=type_hints["plugins"])
             check_type(argname="argument seed_jobs", value=seed_jobs, expected_type=type_hints["seed_jobs"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if base_plugins is not None:
             self._values["base_plugins"] = base_plugins
         if disable_csrf_protection is not None:
@@ -358,7 +332,7 @@ class JenkinsProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def metadata(self) -> typing.Optional[cdk8s.ApiObjectMetadata]:
+    def metadata(self) -> typing.Optional[_cdk8s_d3d9af27.ApiObjectMetadata]:
         '''Metadata associated with Jenkins resource.
 
         :default:
@@ -374,7 +348,7 @@ class JenkinsProps:
         }
         '''
         result = self._values.get("metadata")
-        return typing.cast(typing.Optional[cdk8s.ApiObjectMetadata], result)
+        return typing.cast(typing.Optional[_cdk8s_d3d9af27.ApiObjectMetadata], result)
 
     @builtins.property
     def plugins(self) -> typing.Optional[typing.List["Plugin"]]:
@@ -428,18 +402,11 @@ class Plugin:
         :param download_url: The url from where plugin has to be downloaded. Default: - Plugins are downloaded from Jenkins Update Centers.
         '''
         if __debug__:
-            def stub(
-                *,
-                name: builtins.str,
-                version: builtins.str,
-                download_url: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__51f7089b5b7f7938f285f2c97238625261f191e9c733e268baab733d8d38d1b5)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument version", value=version, expected_type=type_hints["version"])
             check_type(argname="argument download_url", value=download_url, expected_type=type_hints["download_url"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
             "version": version,
         }
@@ -513,22 +480,13 @@ class SeedJob:
         :param targets: The repository path where seed job definitions are present.
         '''
         if __debug__:
-            def stub(
-                *,
-                description: builtins.str,
-                id: builtins.str,
-                repository_branch: builtins.str,
-                repository_url: builtins.str,
-                targets: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f95ca97b71e9b5886de21dc226c0666de7cd25c282df40f4d7b760c008fd659e)
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument repository_branch", value=repository_branch, expected_type=type_hints["repository_branch"])
             check_type(argname="argument repository_url", value=repository_url, expected_type=type_hints["repository_url"])
             check_type(argname="argument targets", value=targets, expected_type=type_hints["targets"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "description": description,
             "id": id,
             "repository_branch": repository_branch,
@@ -594,3 +552,65 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__72446e34172d3900118a01d2f5e7fe405c06fd092747e126f4819104c9f6d7d3(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    base_plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[builtins.str, typing.Any]]]] = None,
+    disable_csrf_protection: typing.Optional[builtins.bool] = None,
+    metadata: typing.Optional[typing.Union[_cdk8s_d3d9af27.ApiObjectMetadata, typing.Dict[builtins.str, typing.Any]]] = None,
+    plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[builtins.str, typing.Any]]]] = None,
+    seed_jobs: typing.Optional[typing.Sequence[typing.Union[SeedJob, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__edc4fd6cb9750a65e94c6c1c74a03d3e5465f85379bd8321d629a5047bead71d(
+    *base_plugins: Plugin,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2a208fc11ec0b64c7c29ad72d3b747209215402bf303d0e87f9a1c27deabd6dd(
+    *plugins: Plugin,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__37b0c91af96e55de36855241220aef3530626841a1131387d44e140e073c145d(
+    *seed_jobs: SeedJob,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1a459058700d681813edb30fad5bba411efe07ec08e129aedf47aceff4bc7536(
+    *,
+    base_plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[builtins.str, typing.Any]]]] = None,
+    disable_csrf_protection: typing.Optional[builtins.bool] = None,
+    metadata: typing.Optional[typing.Union[_cdk8s_d3d9af27.ApiObjectMetadata, typing.Dict[builtins.str, typing.Any]]] = None,
+    plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[builtins.str, typing.Any]]]] = None,
+    seed_jobs: typing.Optional[typing.Sequence[typing.Union[SeedJob, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__51f7089b5b7f7938f285f2c97238625261f191e9c733e268baab733d8d38d1b5(
+    *,
+    name: builtins.str,
+    version: builtins.str,
+    download_url: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f95ca97b71e9b5886de21dc226c0666de7cd25c282df40f4d7b760c008fd659e(
+    *,
+    description: builtins.str,
+    id: builtins.str,
+    repository_branch: builtins.str,
+    repository_url: builtins.str,
+    targets: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
